abacusai.api_class.connectors — AbacusAI documentation

# abacusai.api_class.connectors

## Classes

`StreamingConnectorDatasetConfig` | An abstract class for dataset configs specific to streaming connectors.
`KafkaDatasetConfig` | Dataset config for Kafka Streaming Connector
`_StreamingConnectorDatasetConfigFactory` | Helper class that provides a standard way to create an ABC using

## Module Contents

class abacusai.api_class.connectors.StreamingConnectorDatasetConfig

  Bases: `abacusai.api_class.dataset.DatasetConfig`

  An abstract class for dataset configs specific to streaming connectors.

  Parameters:

    streaming_connector_type (StreamingConnectorType) – The type of streaming connector

  streaming_connector_type: abacusai.api_class.enums.StreamingConnectorType
  classmethod _get_builder()

class abacusai.api_class.connectors.KafkaDatasetConfig

  Bases: `StreamingConnectorDatasetConfig`

  Dataset config for Kafka Streaming Connector

  Parameters:

    topic (str) – The kafka topic to consume

  topic: str
  __post_init__()

class abacusai.api_class.connectors._StreamingConnectorDatasetConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'streaming_connector_type'
  config_class_map